==> xfwm4-4.1.0-cvs.tar.gz: xfwm4-4.1.0/src/focus.h <==
/*
        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; You may only use version 2 of the License,
        you have no option to use any other version.
 
        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.
 
        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
        xfwm4    - (c) 2002-2004 Olivier Fourdan
 
 */

#ifndef INC_FOCUS_H
#define INC_FOCUS_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <glib.h>
#include "client.h"

#define NO_FOCUS_FLAG                   0
#define FOCUS_SORT                      (1<<0)
#define FOCUS_IGNORE_MODAL              (1<<1)
#define FOCUS_FORCE                     (1<<2)

void            clientFocusTop (int);
void 		clientFocusNew(Client *);
gboolean 	clientSelectMask (Client *, int);
Client 	       *clientGetNext (Client *, int);
Client         *clientGetPrevious (Client *, int);
void 		clientPassFocus (Client *);
gboolean 	clientAcceptFocus (Client *);
void 		clientSortRing(Client *);
void 		clientUpdateFocus (Client *, unsigned short);
void            clientClearFocus (void);
void            clientGrabButton1 (Client *);
void            clientUngrabButton1 (Client *);
void            clientPassGrabButton1(Client *);
Client         *clientGetLastGrab (void);
void            clientClearLastGrab (void);

#endif /* INC_FOCUS_H */

==> xfwm4-4.1.3-cvs.tar.gz: xfwm4-4.1.3/src/focus.h <==
/*
        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2, or (at your option)
        any later version.
 
        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.
 
        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
        xfwm4    - (c) 2002-2004 Olivier Fourdan
 
 */

#ifndef INC_FOCUS_H
#define INC_FOCUS_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <glib.h>
#include <sys/time.h>
#include "screen.h"
#include "client.h"

#define NO_FOCUS_FLAG                   0
#define FOCUS_SORT                      (1<<0)
#define FOCUS_IGNORE_MODAL              (1<<1)
#define FOCUS_FORCE                     (1<<2)

void            clientFocusTop (ScreenData *, int);
void            clientFocusNew(Client *);
gboolean        clientSelectMask (Client *, int);
Client         *clientGetNext (Client *, int);
Client         *clientGetPrevious (Client *, int);
void            clientPassFocus (ScreenData *, Client *);
gboolean        clientAcceptFocus (Client *);
void            clientSortRing(Client *);
void            clientUpdateFocus (ScreenData *, Client *, unsigned short);
void            clientSetFocus (ScreenData *, Client *, Time, unsigned short);
void            clientClearFocus (void);
Client         *clientGetFocus (void);
void            clientGrabButton1 (Client *);
void            clientUngrabButton1 (Client *);
void            clientPassGrabButton1(Client *);
Client         *clientGetLastGrab (void);
void            clientClearLastGrab (void);

#endif /* INC_FOCUS_H */
